AiIntegrationSettings class

Constructors

AiIntegrationSettings({required AiProvider provider, required AiProviderKeySettings gemini, required AiProviderKeySettings openai, required AiProviderKeySettings claude, required AiProviderKeySettings groq, required AiProviderKeySettings cerebras})
const
AiIntegrationSettings.fromJson(Map<String, dynamic> json)
factory

Properties

cerebras AiProviderKeySettings
final
claude AiProviderKeySettings
final
gemini AiProviderKeySettings
final
groq AiProviderKeySettings
final
hashCode int
The hash code for this object.
no setterinherited
openai AiProviderKeySettings
final
provider AiProvider
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited