AnonymousAccount class

Constructors

AnonymousAccount({required String id, String? displayName, required DateTime createdAt, required DateTime lastSeenAt})
const
AnonymousAccount.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime
final
displayName String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
lastSeenAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited