SurveyResults class
Constructors
-
SurveyResults({required int surveyId, required int totalResponses, required List<
QuestionResult> questionResults}) -
const
-
SurveyResults.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
questionResults
→ List<
QuestionResult> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surveyId → int
-
final
- totalResponses → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited