AnonymousEndpoint class
Constructors
- AnonymousEndpoint(Client _client)
Properties
- account ↔ AnonymousAccount?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAuthenticated → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token ↔ String?
-
getter/setter pair
Methods
-
clear(
) → void -
createAccount(
{String? displayName}) → Future< AnonymousSession> -
getLatestReplyAt(
{int? responseId}) → Future< DateTime?> -
getReplies(
{int? responseId}) → Future< List< AdminReply> > -
me(
) → Future< AnonymousAccount> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
useToken(
String token, {AnonymousAccount? account}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited